@@ -1,7 +1,8 @@
 #!/usr/bin/python
 
 from gvoice import *
-from gvSMS import Ui_MainWindow
+from gvSMSPeople import Ui_MainWindow
+from gvSMSMsg import Ui_MsgWindow
 from gvAccount import *
 import sys
 import os
@@ -93,6 +94,15 @@ def createPDUstring(number, msg):
     pdu_message.extend(octifiedmsg)
     return pdu_message
 
+# remove unnecessary characters from phone number
+def cleansenumber(number):
+    stripchars = '()- '
+    
+    cleannumber = number
+    for c in stripchars:
+        cleannumber = cleannumber.replace(c, "")
+    return(cleannumber)
+
 class SMS(object):
     '''
     Sends sms messages
@@ -123,18 +133,12 @@ class MainWindow(QMainWindow, Ui_MainWindow):
     def __init__(self, parent=None):
         super(MainWindow, self).__init__(parent)
         self.setupUi(self)
-        self.plainTextEditMessage.setEnabled(False)
-        self.plainTextEditStatus.setReadOnly(True)
-        self.radioButtonPhone.setChecked(True)
+        self.pushButtonNext.setEnabled(False)
         self.email = ""
         self.password = ""
-        # fix up the LCD color
-	palette = self.lcdNumberCharacterCount.palette();
-	palette.setColor(QPalette.Normal, QPalette.Foreground, Qt.red);
-	palette.setColor(QPalette.Normal, QPalette.Background, Qt.black);
-	palette.setColor(QPalette.Normal, QPalette.Light, Qt.white);
-	palette.setColor(QPalette.Normal, QPalette.Dark, Qt.lightGray);
-	self.lcdNumberCharacterCount.setPalette(palette);
+        self.msgWindow = MsgWindow(self)
+        self.msgWindow.hide()
+        self.mobile_numbers = []
 
         #pyside 0.2.2 bug? auto-connect of signals is not working
         #self.connect(self.pushButtonSend, SIGNAL("released()"), self.on_pushButtonSend_released)
@@ -208,15 +212,107 @@ class MainWindow(QMainWindow, Ui_MainWindow):
              # final list of contacts to contact
              self.contact_selector = ContactSelector(contact_loader.contacts_by_group_list)
              # save a copy to reload after any deletes
-             self.save_contacts_by_group_list = copy.deepcopy(contact_loader.contacts_by_group_list)
+             #self.save_contacts_by_group_list = copy.deepcopy(contact_loader.contacts_by_group_list)
              group_list = self.contact_selector.get_group_list()
              for group_item in group_list:
                  self.listWidgetGroups.addItem(group_item[1])
 
+    def on_listWidgetGroups_itemClicked(self, item):
+        # reload original list in case user has deleted any
+        #local_contacts_by_group_list = copy.deepcopy(ui.save_contacts_by_group_list)
+        #self.contact_selector = ContactSelector(local_contacts_by_group_list)
+        selected_group = self.listWidgetGroups.row(item) + 1
+        self.contact_selector.set_selected_group(selected_group)
+        self.listWidgetPeople.clear()
+        self.mobile_numbers = []
+        for contact_item in self.contact_selector.get_contacts_list():
+            lwi = QListWidgetItem('%s' % contact_item[1], self.listWidgetPeople)
+            lwi.setFlags(Qt.ItemIsEnabled)
+            lwi.setCheckState(Qt.Checked)
+            self.mobile_numbers.append(cleansenumber(contact_item[1].mobile))
+            #self.listWidgetPeople.addItem('%s' % contact_item[1])
+        if self.listWidgetPeople.count() > 0:
+           self.pushButtonNext.setEnabled(True)
+        else:
+             self.pushButtonNext.setEnabled(False)
+
+    def on_listWidgetPeople_itemClicked(self, item):
+        if item.flags() & Qt.ItemIsEnabled:
+            item.setCheckState(Qt.Unchecked)
+            item.setFlags(Qt.NoItemFlags)
+        else:
+            item.setCheckState(Qt.Checked)
+            item.setFlags(Qt.ItemIsEnabled)
+        
+        '''
+        reply = QtGui.QMessageBox.question(self, 'Remove?',
+        "Remove " + '%s' % item.text() + " from list?", QtGui.QMessageBox.Yes, QtGui.QMessageBox.No)
+        if reply == QtGui.QMessageBox.Yes:
+           index = self.listWidgetPeople.row(item)
+           self.listWidgetPeople.takeItem(index)
+           contact_list = [index+1]
+           self.contact_selector.remove_from_contact_list(contact_list)
+           if self.listWidgetPeople.count() > 0:
+              self.pushButtonNext.setEnabled(True)
+           else:
+              self.pushButtonNext.setEnabled(False)
+        '''
+
+    @QtCore.pyqtSlot()
+    def on_actionLog_In_triggered(self):
+        self.email = ""
+        self.password = ""
+        self.load_config()
+        
+    def on_pushButtonNext_released(self):
+        self.msgWindow.show()
+
+class MsgWindow(QMainWindow, Ui_MsgWindow):
+
+    def __init__(self, parent=None):
+        super(MsgWindow, self).__init__(parent)
+        self.setupUi(self)
+        self.radioButtonPhone.setChecked(True)
+        self.pushButtonSend.setEnabled(False)
+        # fix up the LCD color
+        palette = self.lcdNumberCharacterCount.palette();
+        palette.setColor(QPalette.Normal, QPalette.Foreground, Qt.red);
+        palette.setColor(QPalette.Normal, QPalette.Background, Qt.black);
+        palette.setColor(QPalette.Normal, QPalette.Light, Qt.white);
+        palette.setColor(QPalette.Normal, QPalette.Dark, Qt.lightGray);
+        self.lcdNumberCharacterCount.setPalette(palette);
+
     def on_pushButtonSend_released(self):
-        text_sender = TextSender(self.gv.opener, self.gv.key)
+        text_sender = TextSender(ui.gv.opener, ui.gv.key)
         text_sender.text = self.plainTextEditMessage.toPlainText()
-        for contact in self.contact_selector.get_contacts_list():
+        
+        itemcount = ui.listWidgetPeople.count()
+        i = 0
+        while i < itemcount:
+            number = ui.mobile_numbers[i]
+            thisitem = ui.listWidgetPeople.item(i)
+            name = thisitem.text()
+            if thisitem.flags() & Qt.ItemIsEnabled:
+                if number == '':
+                    self.plainTextEditStatus.appendPlainText('%s does not have a mobile number' % name)
+                else:
+                    message = 'Sending message to %s at %s...' % (name, number)
+                    if self.radioButtonPhone.isChecked():
+                        sms = SMS(text_sender.text.toAscii(), number)
+                        sms.send()
+                        #sms.print_pdustring()
+                        sending_result = sms.response
+                    else: #send via Google
+                      text_sender.send_text(number)
+                      sending_result = text_sender.response
+                    if sending_result:
+                        self.plainTextEditStatus.appendPlainText(message + "Success!")
+                    else:
+                        self.plainTextEditStatus.appendPlainText(message + "Failed!!")
+            i = i + 1
+            
+        '''
+        for contact in ui.contact_selector.get_contacts_list():
             number = contact[1].mobile
             if number == '':
                self.plainTextEditStatus.appendPlainText('%s does not have a mobile number' % contact[1])
@@ -234,37 +330,15 @@ class MainWindow(QMainWindow, Ui_MainWindow):
                     self.plainTextEditStatus.appendPlainText(message + "Success!")
                  else:
                       self.plainTextEditStatus.appendPlainText(message + "Failed!!")
-
-    def on_listWidgetGroups_itemClicked(self, item):
-        # reload original list in case user has deleted any
-        local_contacts_by_group_list = copy.deepcopy(self.save_contacts_by_group_list)
-        self.contact_selector = ContactSelector(local_contacts_by_group_list)
-        selected_group = self.listWidgetGroups.row(item) + 1
-        self.contact_selector.set_selected_group(selected_group)
-        self.listWidgetPeople.clear()
-        for contact_item in self.contact_selector.get_contacts_list():
-            self.listWidgetPeople.addItem('%s' % contact_item[1])
-        if self.listWidgetPeople.count() > 0:
-           self.plainTextEditMessage.setEnabled(True)
-        else:
-             self.plainTextEditMessage.setEnabled(False)
-
-    def on_listWidgetPeople_itemClicked(self, item):
-        reply = QtGui.QMessageBox.question(self, 'Remove?',
-        "Remove " + '%s' % item.text() + " from list?", QtGui.QMessageBox.Yes, QtGui.QMessageBox.No)
-        if reply == QtGui.QMessageBox.Yes:
-           index = self.listWidgetPeople.row(item)
-           self.listWidgetPeople.takeItem(index)
-           contact_list = [index+1]
-           self.contact_selector.remove_from_contact_list(contact_list)
-           if self.listWidgetPeople.count() > 0:
-              self.plainTextEditMessage.setEnabled(True)
-           else:
-              self.plainTextEditMessage.setEnabled(False)
+        '''
 
     def on_plainTextEditMessage_textChanged(self):
         message = self.plainTextEditMessage.toPlainText()
         self.lcdNumberCharacterCount.display(message.length())
+        if (message.length() > 0):
+           self.pushButtonSend.setEnabled(True)
+        else:
+             self.pushButtonSend.setEnabled(False)
 
     @QtCore.pyqtSlot()
     def on_actionLog_In_triggered(self):
